@@ -27,16 +27,16 @@
 #include "config.h"
 #include "tag.h"
 
-#include <kapplication.h>
-#include <kglobal.h>
-#include <kconfig.h>
+#include <tdeapplication.h>
+#include <tdeglobal.h>
+#include <tdeconfig.h>
 #include <kiconloader.h>
-#include <kfiledialog.h>
-#include <kmessagebox.h>
+#include <tdefiledialog.h>
+#include <tdemessagebox.h>
 #include <tqdir.h>
 #include <tqfile.h>
 #include <tqpainter.h>
-#include <kglobalsettings.h>
+#include <tdeglobalsettings.h>
 #include <kprogress.h>
 
 HTMLExporter::HTMLExporter(Basket *basket)
@@ -44,7 +44,7 @@ HTMLExporter::HTMLExporter(Basket *basket)
 	TQDir dir;
 
 	// Compute a default file name & path:
-	KConfig *config = KGlobal::config();
+	TDEConfig *config = TDEGlobal::config();
 	config->setGroup("Export to HTML");
 	TQString folder = config->readEntry("lastFolder", TQDir::homeDirPath()) + "/";
 	TQString url = folder + TQString(basket->basketName()).replace("/", "_") + ".html";
@@ -65,7 +65,7 @@ HTMLExporter::HTMLExporter(Basket *basket)
 				"<qt>" + i18n("The file <b>%1</b> already exists. Do you really want to override it?")
 					.arg(KURL(destination).fileName()),
 				i18n("Override File?"),
-				KGuiItem(i18n("&Override"), "filesave")
+				KGuiItem(i18n("&Override"), "document-save")
 			);
 			if (result == KMessageBox::Cancel)
 				return;
@@ -232,8 +232,8 @@ void HTMLExporter::exportBasket(Basket *basket, bool isSubBasket)
 			"   .tree span { -moz-border-radius: 6px; display: block; float: left;\n"
 			"                line-height: 16px; height: 16px; vertical-align: middle; padding: 0 1px; }\n"
 			"   .tree img { vertical-align: top; padding-right: 1px; }\n"
-			"   .tree .current { background-color: " << KGlobalSettings::highlightColor().name() << "; "
-			                    "-moz-border-radius: 3px 0 0 3px; border-radius: 3px 0 0 3px; color: " << KGlobalSettings::highlightedTextColor().name() << "; }\n"
+			"   .tree .current { background-color: " << TDEGlobalSettings::highlightColor().name() << "; "
+			                    "-moz-border-radius: 3px 0 0 3px; border-radius: 3px 0 0 3px; color: " << TDEGlobalSettings::highlightedTextColor().name() << "; }\n"
 			"   .basketSurrounder { margin-left: 152px; _margin: 0; _float: right; }\n";
 	}
 	stream <<
@@ -316,7 +316,7 @@ void HTMLExporter::exportBasket(Basket *basket, bool isSubBasket)
 	stream << TQString(
 		"  </div>\n"
 		"  <p class=\"credits\">%1</p>\n").arg(
-			i18n("Made with %1, a KDE tool to take notes and keep information at hand.")
+			i18n("Made with %1, a TDE tool to take notes and keep information at hand.")
 				.arg("<a href=\"http://basket.kde.org/\">%1</a> %2")
 				.arg(kapp->aboutData()->programName(), VERSION));
 
@@ -550,11 +550,11 @@ TQString HTMLExporter::copyFile(const TQString &srcPath, bool createIt)
 		if (file.open(IO_WriteOnly))
 			file.close();
 		// And then we copy the file AND overwriting the file we juste created:
-		new KIO::FileCopyJob(
+		new TDEIO::FileCopyJob(
 			KURL(srcPath), KURL(fullPath), 0666, /*move=*/false,
 			/*overwrite=*/true, /*resume=*/true, /*showProgress=*/false );
 	} else
-		/*KIO::CopyJob *copyJob = */KIO::copy(KURL(srcPath), KURL(fullPath)); // Do it as before
+		/*TDEIO::CopyJob *copyJob = */TDEIO::copy(KURL(srcPath), KURL(fullPath)); // Do it as before
 
 	return fileName;
 }
