@@ -21,13 +21,13 @@
 #include <tqstring.h>
 #include <tqdir.h>
 #include <kstandarddirs.h>
-#include <klocale.h>
-#include <kfiledialog.h>
+#include <tdelocale.h>
+#include <tdefiledialog.h>
 #include <tqptrstack.h>
 #include <tqlayout.h>
 #include <tqvbuttongroup.h>
 #include <tqradiobutton.h>
-#include <kmessagebox.h>
+#include <tdemessagebox.h>
 #include <tqtextedit.h>
 
 #include "softwareimporters.h"
@@ -345,7 +345,7 @@ void SoftwareImporters::importKNotes()
 					inDescription = true;
 				} else if (inDescription && buf.startsWith(" ")) {
 					body += buf.mid(1, buf.length());
-				} else if (buf.startsWith("X-KDE-KNotes-RichText:")) {
+				} else if (buf.startsWith("X-TDE-KNotes-RichText:")) {
 					isRichText = XMLWork::trueOrFalse(buf.mid(22, buf.length() - 22).stripWhiteSpace(), "false");
 				} else if (buf == "END:VJOURNAL") {
 					insertTitledNote(basket, fromICS(title), fromICS(body), (isRichText ? TQt::RichText : TQt::PlainText));
@@ -492,7 +492,7 @@ void SoftwareImporters::importTextFile()
 
 		// First create a basket for it:
 		TQString title = i18n("From TextFile.txt", "From %1").arg(KURL(fileName).fileName());
-		BasketFactory::newBasket(/*icon=*/"txt", title, /*backgroundImage=*/"", /*backgroundColor=*/TQColor(), /*textColor=*/TQColor(), /*templateName=*/"1column", /*createIn=*/0);
+		BasketFactory::newBasket(/*icon=*/"text-plain", title, /*backgroundImage=*/"", /*backgroundColor=*/TQColor(), /*textColor=*/TQColor(), /*templateName=*/"1column", /*createIn=*/0);
 		Basket *basket = Global::bnpView->currentBasket();
 		basket->load();
 
